c: Concatenation

cR Documentation

Concatenation

Description

Combines its arguments to form a single jordan object.

Usage

## S4 method for signature 'jordan'
c(x,...)

Arguments

x, ...

Jordan objects

Details

Returns a concatenated jordan of the same type as its arguments. Argument checking is not performed.

Value

Returns a Jordan object of the appropriate type (coercion is not performed)

Note

Names are inherited from the behaviour of cbind(), not c().

Author(s)

Robin K. S. Hankin

Examples

c(rqhm(),rqhm()*10)

jordan documentation built on Sept. 21, 2026, 9:06 a.m.