jordan: Create jordan objects

jordanR Documentation

Create jordan objects

Description

Creation methods for jordan objects

Usage

is.real_symmetric_matrix(x)
is.quaternion_herm_matrix(x)
quaternion_herm_matrix(M)
complex_herm_matrix(M)
is.complex_herm_matrix(x)
real_symmetric_matrix(M)
albert(M)
is.albert(x)
is.jordan(x)
as.spin(x, d)
is.spin(x)
spin(a, V)

Arguments

M

A matrix with columns representing independent entries in a matrix-based Jordan algebra

x

Object to be tested

a, V

Scalar and vector components of a spin factor

d

Dimensionality of vector component of a spin factor

Details

The functions documented here are the creation methods for the five types of jordan algebra.

  • quaternion_herm_matrix()

  • complex_herm_matrix()

  • real_symmetric_matrix()

  • albert()

  • spin()

(to generate quick “get you going” Jordan algebra objects, use the rrsm() family of functions, documented at random.Rd).

Value

Return jordans or Boolean as appropriate

Author(s)

Robin K. S. Hankin

See Also

random

Examples


A <- real_symmetric_matrix(1:10)  # vector of length 1
as.1matrix(A)                     # in matrix form

complex_herm_matrix(cbind(1:25,2:26))
quaternion_herm_matrix(1:15)

albert(1:27)
spin(-6,cbind(1:12,12:1))


x <- rrsm() ; y <- rrsm() ; z <- rrsm()  # also works with the other Jordans

x*(y*z) - (x*y)*z         # Jordan algebra is not associative...
(x*y)*(x*x) - x*(y*(x*x)) # but satisfies the Jordan identity



jordan documentation built on Sept. 21, 2026, 9:06 a.m.